@@ -26,8 +26,9 @@ from dragg_comp.agent import RandomAgent
 REDIS_URL = "redis://localhost"
 
 class PlayerHome(gym.Env):
-    def __init__(self):
+    def __init__(self, redis_url=REDIS_URL):
         self.nstep = 0
+        self.redis_url = redis_url
         asyncio.run(self.await_status("ready"))
         home = self.set_home()
         self.home = MPCCalc(home)
@@ -47,19 +48,29 @@ class PlayerHome(gym.Env):
                 a_min += [42]
                 a_max += [52]
             elif action == "ev_charge":
-                a_min += [0]
-                a_max += [16]
+                a_min += [-1]
+                a_max += [1]
         self.action_space = Box(np.array(a_min), np.array(a_max))
         asyncio.run(self.post_status("initialized player"))
         asyncio.run(self.await_status("all ready"))
         self.demand_profile = []
+        self.reset(initialize=True)
 
-    def reset(self):
+    def reset(self, initialize=False):
         """
         Reset as required by OpenAI gym. Beta implementation simply returns current observation, 
         meaning that the simulation will overall continue running. 
         :return: state vector of length n
         """
+        if initialize:
+            self.home.redis_get_initial_values()
+            self.home.cast_redis_timestep()
+            self.home.get_initial_conditions()
+            self.home.add_type_constraints()
+            self.home.set_type_p_grid()
+            self.home.solve_mpc(debug=True)
+            self.home.cleanup_and_finish()
+
         obs = self.get_obs()
 
         return obs 
@@ -147,6 +158,10 @@ class PlayerHome(gym.Env):
         :return: dictionary of key performance indexes
         """
         kpis = {"std_demand": np.std(self.demand_profile), "max_demand": np.max(self.demand_profile)}
+
+        with open("score.txt", 'w'):
+            kpis.write(json.dumps(kpis))
+
         return kpis
 
     def step(self, action=None):
@@ -204,7 +219,7 @@ class PlayerHome(gym.Env):
         Opens and asynchronous reader and awaits the specified status
         :return: None
         """
-        async_redis = aioredis.from_url(REDIS_URL)
+        async_redis = aioredis.from_url(self.redis_url)
         pubsub = async_redis.pubsub()
         await pubsub.subscribe("channel:1", "channel:2")
 
@@ -229,7 +244,7 @@ class PlayerHome(gym.Env):
         Publishes a status (typically "is done" to alert the aggregator)
         :return: None
         """
-        async_redis = aioredis.from_url(REDIS_URL)
+        async_redis = aioredis.from_url(self.redis_url)
         pubsub = async_redis.pubsub()
         await pubsub.subscribe("channel:1")
         print(f"{self.home.name} {status} at t = {self.nstep}.")
