@@ -29,8 +29,9 @@ from dragg.logger import Logger
 REDIS_URL = "redis://localhost"
 
 class RLAggregator(Aggregator):
-    def __init__(self):
-        super().__init__()
+    def __init__(self, start=None, end=None, redis_url=REDIS_URL):
+        self.redis_url = redis_url
+        super().__init__(start, end)
         self.mpc_players = [] # RLAggregator distinguishes between comp controlled (mpc_players) and human players
 
     def get_homes(self):
@@ -88,7 +89,7 @@ class RLAggregator(Aggregator):
         Publishes a status (typically "is done" to alert the aggregator)
         :return: None
         """
-        async_redis = aioredis.from_url(REDIS_URL)
+        async_redis = aioredis.from_url(self.redis_url)
         pubsub = async_redis.pubsub()
         await pubsub.subscribe("channel:1")
         await async_redis.publish("channel:1", f"{status}.")
@@ -194,5 +195,5 @@ class RLAggregator(Aggregator):
         await asyncio.create_task(self.reader(pubsub, redis))
 
 if __name__=="__main__":
-    a = RLAggregator()
+    a = RLAggregator(sys.argv[1], sys.argv[2])
     asyncio.run(a.open_server())
